@@ -1,2 +1,5 @@
-quantile.mcmc <- function(x, ...)
+quantile.mcmc <- 
+function(x, ...)
+{
     dclone:::quantile.mcmc.list(as.mcmc.list(x), ...)
+}
